@@ -34,7 +34,7 @@ __PACKAGE__->config(
     naked_results         => 0,
 );
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 =head1 NAME
 
@@ -138,14 +138,105 @@ The I<primary_key> value is saved in stash() as C<object_id>.
 sub fetch : Chained('/') PathPrefix CaptureArgs(1) {
     my ( $self, $c, $id ) = @_;
     $c->stash->{object_id} = $id;
-    $c->log->debug("fetching id = $id") if $c->debug;
-    my @arg = $id ? ( $self->primary_key() => $id ) : ();
+    $c->log->debug("fetch $id") if $c->debug;
+    my @pk = $self->get_primary_key( $c, $id );
+    my @arg = $id ? (@pk) : ();
     $c->stash->{object} = $self->do_model( $c, 'fetch', @arg );
     if ( $self->has_errors($c) or !$c->stash->{object} ) {
         $self->throw_error( 'No such ' . $self->model_name );
     }
 }
 
+=head2 get_primary_key( I<context>, I<pk_value> )
+
+Should return an array of the name of the field(s) to fetch() I<pk_value> from
+and their respective values.
+
+The default behaviour is to return B<primary_key> and any corresponding
+value(s) passed via $c->req->params.
+However, if you have other unique fields in your schema, you
+might return a unique field other than the primary key.
+This allows for a more flexible URI scheme.
+
+A good example is Users. A User record might have a numerical id (uid)
+and a username, both of which are unique. So if username 'foobar'
+has a B<primary_key> (uid) of '1234', both these URIs could fetch the same
+record:
+
+ /uri/for/user/1234
+ /uri/for/user/foobar
+
+Again, the default behaviour is to return the B<primary_key> field name(s)
+from config() (accessed via $self->primary_key) but you can override
+get_primary_key() in your subclass to provide more flexibility.
+
+If your primary key is composed of multiple columns, your return value
+should include all those columns and their values as extracted
+from I<pk_value>. Multiple values are assumed to be joined with C<;;>.
+See make_primary_key_string().
+
+=cut
+
+sub get_primary_key {
+    my ( $self, $c, $id ) = @_;
+    return () unless defined $id;
+    my $pk = $self->primary_key;
+    my @ret;
+    if ( ref $pk ) {
+        my @val = split( m/;;/, $id );
+        for my $col (@$pk) {
+            my $v
+                = exists $c->req->params->{$col}
+                ? $c->req->params->{$col}
+                : shift(@val);
+            push( @ret, $col => $v );
+        }
+    }
+    else {
+        @ret
+            = ( $pk => exists $c->req->params->{$pk}
+            ? $c->req->params->{$pk}
+            : $id );
+    }
+    return @ret;
+}
+
+=head2 make_primary_key_string( I<object> )
+
+Using value of B<primary_string> constructs a URI-ready
+string based on values in I<object>. I<object> is often
+the value of:
+ 
+ $c->stash->{object}
+
+but could be any object that has accessor methods with
+the same names as the field(s) specified by B<primary_key>.
+
+Multiple values are joined with C<;;> and any C<;> characters
+in the column values are URI-escaped.
+
+=cut
+
+sub make_primary_key_string {
+    my ( $self, $obj ) = @_;
+    my $pk = $self->primary_key;
+    my $id;
+    if ( ref $pk ) {
+        my @vals;
+        for my $field (@$pk) {
+            my $v = scalar $obj->$field;
+            $v = '' unless defined $v;
+            $v =~ s/;/ sprintf( "%%%02X", ';' ) /eg;
+            push( @vals, $v );
+        }
+        $id = join( ';;', @vals );
+    }
+    else {
+        $id = $obj->$pk;
+    }
+    return $id;
+}
+
 =head2 create
 
 Attribute: Local
@@ -406,7 +497,7 @@ sub do_model {
     my $c      = shift or $self->throw_error("context required");
     my $method = shift or $self->throw_error("method required");
     if ( $self->model_adapter ) {
-        return $self->model_adapter->$method( $c, @_ );
+        return $self->model_adapter->$method( $self, $c, @_ );
     }
     else {
         return $c->model( $self->model_name )->$method(@_);
@@ -544,13 +635,14 @@ redirect resolving to view().
 
 sub postcommit {
     my ( $self, $c, $o ) = @_;
-    my $pk = $self->primary_key;
+
+    my $id = $self->make_primary_key_string($o);
 
     if ( $c->action->name eq 'rm' ) {
         $c->response->redirect( $c->uri_for('') );
     }
     else {
-        $c->response->redirect( $c->uri_for( '', $o->$pk, 'view' ) );
+        $c->response->redirect( $c->uri_for( '', $id, 'view' ) );
     }
 
     1;
@@ -569,14 +661,13 @@ action in the same class as the current action.
 sub view_on_single_result {
     my ( $self, $c, $results ) = @_;
     return 0 unless $self->config->{view_on_single_result};
-    my $pk  = $self->primary_key;
     my $obj = $results->[0];
+    my $id  = $self->make_primary_key_string($obj);
 
     # the append . '' is to force stringify anything
     # that might be an object with overloading. Otherwise
     # uri_for() assumes it is an Action object.
-    return $c->uri_for( $obj->$pk . '',
-        $self->can_write($c) ? 'edit' : 'view' );
+    return $c->uri_for( $id . '', $self->can_write($c) ? 'edit' : 'view' );
 }
 
 =head2 make_query( I<context>, I<arg> )
@@ -679,6 +770,9 @@ The following methods simply return the config() value of the same name.
 
 =item primary_key
 
+primary_key may be a single column name or an array ref of multiple
+column names.
+
 =item page_size
 
 =item allow_GET_writes
