@@ -7,7 +7,7 @@ use base qw( Class::Accessor::Fast );
 
 __PACKAGE__->mk_accessors(qw( params fields ));
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 =head1 NAME
 
@@ -58,12 +58,18 @@ sub new {
     return $self;
 }
 
+*field_names = \&fields;
+
 =head2 fields( [ I<arrayref> ] )
 
 Get/set the arrayref of field names.
 
 This must be set in new().
 
+=head2 field_names
+
+An alias for fields().
+
 =head2 params( [ I<hashref> ] )
 
 Get/set the hashref of key/value pairs for the form object. The keys should
